fn present<T: Serialize>(value: T) -> PartialFieldExpand description
A PartialField holding a value that is always present in the typed
struct.
fn present<T: Serialize>(value: T) -> PartialFieldA PartialField holding a value that is always present in the typed
struct.